==> qt6-webengine_6.8.2+dfsg.orig.tar.xz: qtwebengine-everywhere-src-6.8.2/src/3rdparty/chromium/chrome/browser/ui/webui/ash/login/user_allowlist_check_screen_handler.cc <==
// Copyright 2023 The Chromium Authors
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#include "chrome/browser/ui/webui/ash/login/user_allowlist_check_screen_handler.h"

#include "base/logging.h"
#include "chrome/browser/ash/login/oobe_screen.h"
#include "chrome/browser/ash/login/screens/user_allowlist_check_screen.h"
#include "chrome/grit/generated_resources.h"
#include "components/login/localized_values_builder.h"

namespace ash {

UserAllowlistCheckScreenHandler::UserAllowlistCheckScreenHandler()
    : BaseScreenHandler(kScreenId) {}

UserAllowlistCheckScreenHandler::~UserAllowlistCheckScreenHandler() = default;

void UserAllowlistCheckScreenHandler::DeclareLocalizedValues(
    ::login::LocalizedValuesBuilder* builder) {
  builder->Add("allowlistErrorEnterpriseAndFamilyLink",
               IDS_ENTERPRISE_AND_FAMILY_LINK_LOGIN_ERROR_ALLOWLIST);
  builder->Add("allowlistErrorEnterprise",
               IDS_ENTERPRISE_LOGIN_ERROR_ALLOWLIST);
  builder->Add("allowlistErrorConsumer", IDS_LOGIN_ERROR_ALLOWLIST);
  builder->Add("tryAgainButton", IDS_ALLOWLIST_ERROR_TRY_AGAIN_BUTTON);
}

void UserAllowlistCheckScreenHandler::DeclareJSCallbacks() {}

void UserAllowlistCheckScreenHandler::Show(bool enterprise_managed,
                                           bool family_link_allowed) {
  base::Value::Dict params;
  params.Set("enterpriseManaged", enterprise_managed);
  params.Set("familyLinkAllowed", family_link_allowed);
  ShowInWebUI(std::move(params));
}

void UserAllowlistCheckScreenHandler::Hide() {}

}  // namespace ash

==> qt6-webengine_6.9.2+dfsg.orig.tar.xz: qtwebengine-everywhere-src-6.9.2/src/3rdparty/chromium/chrome/browser/ui/webui/ash/login/user_allowlist_check_screen_handler.cc <==
// Copyright 2023 The Chromium Authors
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#include "chrome/browser/ui/webui/ash/login/user_allowlist_check_screen_handler.h"

#include "base/logging.h"
#include "chrome/browser/ash/login/oobe_screen.h"
#include "chrome/browser/ash/login/screens/user_allowlist_check_screen.h"
#include "chrome/grit/generated_resources.h"
#include "components/login/localized_values_builder.h"

namespace ash {

UserAllowlistCheckScreenHandler::UserAllowlistCheckScreenHandler()
    : BaseScreenHandler(kScreenId) {}

UserAllowlistCheckScreenHandler::~UserAllowlistCheckScreenHandler() = default;

void UserAllowlistCheckScreenHandler::DeclareLocalizedValues(
    ::login::LocalizedValuesBuilder* builder) {
  builder->Add("allowlistErrorEnterpriseAndFamilyLink",
               IDS_ENTERPRISE_AND_FAMILY_LINK_LOGIN_ERROR_ALLOWLIST);
  builder->Add("allowlistErrorEnterprise",
               IDS_ENTERPRISE_LOGIN_ERROR_ALLOWLIST);
  builder->Add("allowlistErrorConsumer", IDS_LOGIN_ERROR_ALLOWLIST);
  builder->Add("tryAgainButton", IDS_ALLOWLIST_ERROR_TRY_AGAIN_BUTTON);
}

void UserAllowlistCheckScreenHandler::DeclareJSCallbacks() {}

void UserAllowlistCheckScreenHandler::Show(bool enterprise_managed,
                                           bool family_link_allowed) {
  base::Value::Dict params;
  params.Set("enterpriseManaged", enterprise_managed);
  params.Set("familyLinkAllowed", family_link_allowed);
  ShowInWebUI(std::move(params));
}

void UserAllowlistCheckScreenHandler::Hide() {}

base::WeakPtr<UserAllowlistCheckScreenView>
UserAllowlistCheckScreenHandler::AsWeakPtr() {
  return weak_factory_.GetWeakPtr();
}

}  // namespace ash
